@@ -66,6 +66,7 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
 
     log_config = config.get('logging', DEFAULT_LOG_CONFIG)
 
+    footer_link = config.get('footer_link', {})
     gitlab = config.get('gitlab', {})
     http_settings = config.get('http', {})
     ldap = config.get('ldap', {})
@@ -80,6 +81,11 @@ def load_configuration(config: str, debug: bool) -> typing.Tuple[dict, dict]:
         'compress_response': http_settings.get('compress_response', True),
         'cookie_secret': http_settings.get('cookie_secret', 'imbi'),
         'debug': debug,
+        'footer_link': {
+            'icon': footer_link.get('icon', ''),
+            'text': footer_link.get('text', ''),
+            'url': footer_link.get('url', '')
+        },
         'gitlab_application_id': gitlab.get('application_id'),
         'gitlab_secret': gitlab.get('secret'),
         'gitlab_url': gitlab.get('url', 'https://gitlab.com'),
